EwfIntegrityAnomaly

Enum EwfIntegrityAnomaly 

pub enum EwfIntegrityAnomaly {
Show 24 variants InvalidSignature, SegmentNumberZero, SectionDescriptorCrcMismatch { offset: u64, section_type: String, computed: u32, stored: u32, }, SectionChainBroken { at_offset: u64, next_offset: u64, }, SectionGapNonZero { gap_offset: u64, gap_size: u64, }, VolumeSectionMissing, UnknownSectionType { offset: u64, type_name: String, }, DoneSectionMissing, ChunkSizeInvalid { sectors_per_chunk: u32, bytes_per_sector: u32, }, SectorCountMismatch { declared: u64, expected: u64, }, BytesPerSectorInvalid { bytes_per_sector: u32, }, TableChunkCountMismatch { in_volume: u32, in_table: u32, }, TableEntryOutOfBounds { chunk_index: u32, entry_offset: u64, file_size: u64, }, TableEntryOutsideSectorsRange { chunk_index: u32, entry_offset: u64, sectors_start: u64, sectors_end: u64, }, SectionGapZero { gap_offset: u64, gap_size: u64, }, HashMismatch { computed: [u8; 16], stored: [u8; 16], }, HashSectionMissing, SegmentOutOfOrder { segment_number: u16, expected: u16, }, DigestSha1Mismatch { computed: [u8; 20], stored: [u8; 20], }, ExternalMd5Mismatch { computed: [u8; 16], expected: [u8; 16], }, ExternalSha1Mismatch { computed: [u8; 20], expected: [u8; 20], }, Ewf2SectionDataHashMismatch { offset: u64, section_type_id: u32, computed: [u8; 16], stored: [u8; 16], }, Ewf2EncryptedSection { offset: u64, }, Ewf2HashSectionMissing,
}

Variants



InvalidSignature



SegmentNumberZero



SectionDescriptorCrcMismatch

Fields

offset: u64
section_type: String
computed: u32
stored: u32


SectionChainBroken

Fields

at_offset: u64
next_offset: u64


SectionGapNonZero

Fields

gap_offset: u64
gap_size: u64


VolumeSectionMissing



UnknownSectionType

Fields

offset: u64
type_name: String


DoneSectionMissing



ChunkSizeInvalid

Fields

sectors_per_chunk: u32
bytes_per_sector: u32


SectorCountMismatch

Fields

declared: u64
expected: u64


BytesPerSectorInvalid

Fields

bytes_per_sector: u32


TableChunkCountMismatch

Fields

in_volume: u32
in_table: u32


TableEntryOutOfBounds

Fields

chunk_index: u32
entry_offset: u64
file_size: u64


TableEntryOutsideSectorsRange

Fields

chunk_index: u32
entry_offset: u64
sectors_start: u64
sectors_end: u64


SectionGapZero

Fields

gap_offset: u64
gap_size: u64


HashMismatch

Fields

computed: [u8; 16]
stored: [u8; 16]


HashSectionMissing



SegmentOutOfOrder

Segment number does not match the expected sequential position.

Fields

segment_number: u16
expected: u16


DigestSha1Mismatch

Computed SHA-1 of all sector data does not match the stored SHA-1 in the digest section.

Fields

computed: [u8; 20]
stored: [u8; 20]


ExternalMd5Mismatch

Computed MD5 does not match an externally supplied reference (e.g. chain-of-custody form).

Fields

computed: [u8; 16]
expected: [u8; 16]


ExternalSha1Mismatch

Computed SHA-1 does not match an externally supplied reference.

Fields

computed: [u8; 20]
expected: [u8; 20]


Ewf2SectionDataHashMismatch

A section’s stored data_integrity_hash does not match MD5 of the section body.

Fields

offset: u64
section_type_id: u32
computed: [u8; 16]
stored: [u8; 16]


Ewf2EncryptedSection

An encrypted section was found; its content cannot be verified.

Fields

offset: u64


Ewf2HashSectionMissing

No MD5 or SHA-1 hash section found in the final EWF v2 segment.

Implementations