pub struct ComputedHashes {
pub md5: [u8; 16],
pub sha1: [u8; 20],
pub sha256: [u8; 32],
}Expand description
The three hashes computed over all sector data in an EWF image.
Fields
md5: [u8; 16]sha1: [u8; 20]sha256: [u8; 32]Trait Implementations
Sourceimpl Clone for ComputedHashes
impl Clone for ComputedHashes
Sourcefn clone(&self) -> ComputedHashes
fn clone(&self) -> ComputedHashes
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComputedHashes
impl Debug for ComputedHashes
impl Eq for ComputedHashes
Sourceimpl PartialEq for ComputedHashes
impl PartialEq for ComputedHashes
Sourcefn eq(&self, other: &ComputedHashes) -> bool
fn eq(&self, other: &ComputedHashes) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ComputedHashes